const { makeExecutableSchema } = require('@graphql-tools/schema')
const { execute, Source, parse } = require('graphql')

exports.makeGraphQLApp = function makeGraphQLApp({ schema, resolvers }) {
    const exSchema = makeExecutableSchema({ typeDefs: schema, resolvers })

    return {
        execute: async ({ input, context = {} }) => {
            const source = new Source(input)
            const documentAST = parse(source)
            const x = await execute({
                schema: exSchema,
                document: documentAST,
                contextValue: context
            })

            if (x.errors) {
                return {
                    type: 'error',
                    message: x.errors[0].message
                }
            }

            return {
                type: 'success',
                data: x
            }
        }
    }
}